@@ -6,7 +6,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalDownload.py 6936 2019-07-10 15:52:45Z brideout $
+$Id: globalDownload.py 7369 2021-04-22 17:55:08Z brideout $
 """
 
 usage = """
@@ -19,7 +19,7 @@ usage = """
         where:
 
         --url=<Madrigal url> - url to homepage of site to be searched
-                                  (ie, http://madrigal.haystack.mit.edu/madrigal/)
+                                  (ie, http://madrigal.haystack.mit.edu/)
                                   This is required.
 
         --outputDir=<output directory> - the output directory to store all files in.  Default is to store
@@ -90,7 +90,7 @@ usage = """
         
     Example:
     
-        globalDownload.py --url=http://madrigal.haystack.mit.edu/madrigal --outputDir=/tmp --user_fullname="Bill Rideout" 
+        globalDownload.py --url=http://madrigal.haystack.mit.edu --outputDir=/tmp --user_fullname="Bill Rideout" 
            --user_email=brideout@haystack.mit.edu --user_affiliation=MIT --startDate=01/01/1998 
            --endDate=-01/30/1998 --inst=30
                                     
