@@ -5,7 +5,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalIsprint.py 6932 2019-07-10 15:27:19Z brideout $
+$Id: globalIsprint.py 7369 2021-04-22 17:55:08Z brideout $
 """
 
 usage = """
@@ -18,7 +18,7 @@ usage = """
         where:
 
         --url=<Madrigal url> - url to homepage of site to be searched
-                                  (ie, http://madrigal.haystack.mit.edu/madrigal/)
+                                  (ie, http://madrigal.haystack.mit.edu/)
                                   This is required.
 
         --parms=<Madrigal parms> - a comma delimited string listing the desired Madrigal parameters
